@@ -38,11 +38,18 @@
 #'
 #' dfmat2 <- corpus_subset(data_corpus_inaugural, President == "Obama") %>%
 #'    tokens(remove_punct = TRUE) %>%
-#'    tokens_remove(stopwords("english")) %>%
+#'    tokens_remove(stopwords("en")) %>%
 #'    dfm()
 #' tstat1 <- textstat_frequency(dfmat2)
 #' head(tstat1, 10)
 #'
+#' dfmat3 <- head(data_corpus_inaugural) %>%
+#'    tokens(remove_punct = TRUE) %>%
+#'    tokens_remove(stopwords("en")) %>%
+#'    dfm()
+#' textstat_frequency(dfmat3, n = 2, groups = President)
+#'
+#'
 #' \dontrun{
 #' # plot 20 most frequent words
 #' library("ggplot2")
@@ -54,12 +61,14 @@
 #' # plot relative frequencies by group
 #' dfmat3 <- data_corpus_inaugural %>%
 #'     corpus_subset(Year > 2000) %>%
-#'     dfm(remove = stopwords("english"), remove_punct = TRUE) %>%
-#'     dfm_group(groups = "President") %>%
+#'     tokens(remove_punct = TRUE) %>%
+#'     tokens_remove(stopwords("en")) %>%
+#'     dfm() %>%
+#'     dfm_group(groups = President) %>%
 #'     dfm_weight(scheme = "prop")
 #'
 #' # calculate relative frequency by president
-#' tstat2 <- textstat_frequency(dfmat3, n = 10, groups = "President")
+#' tstat2 <- textstat_frequency(dfmat3, n = 10, groups = President)
 #'
 #' # plot frequencies
 #' ggplot(data = tstat2, aes(x = factor(nrow(tstat2):1), y = frequency)) +
@@ -99,8 +108,15 @@ textstat_frequency.dfm <- function(x, n = NULL, groups = NULL,
     if (!sum(x))
         stop(message_error("dfm_empty"))
 
-    if (is.null(groups))
+    if (missing(groups)) {
         groups <- rep("all", ndoc(x))
+    } else {
+        field <- deparse(substitute(groups))
+        groups <- eval(substitute(groups), get_docvars(x, user = TRUE, system = TRUE), parent.frame())
+        if (!field %in% names(get_docvars(x)) || !is.factor(groups))
+            field <- NULL
+        groups <- as.factor(groups)
+    }
 
     tf <- x
     tf <- dfm_group(tf, groups, ...)
